@@ -177,7 +177,8 @@ class NxPyDocs():
 
     def cleanup(self):
         os.chdir(sys.path[0])
-        os.system("rm -rf nxpydocs")
+        os.system("ls")
+        #os.system("rm -rf nxpydocs")
 
 @click.command()
 @click.option('--command',
